/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 18.07.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.authentication;

import java.util.Date;
import java.io.Serializable;
import javax.security.auth.Subject;

/**
 * Interface AuthenticationContext wraps common authentication states.
 * <p/>
 * The implementation classes are highly depended of {@link org.n52.security.authentication.AuthenticationService} instances,
 * therefor instances are created by the {@link AuthenticationService#createAuthenticationContext()} method.
 *
 * @author Marko Reiprecht
 *         Created on 18.07.2008
 * @version $Revision: $
 */
public interface AuthenticationContext extends Serializable {

    /**
     * Method gets the subject.
     * This is never null.
     *
     * @return Subject.
     */
    Subject getSubject();

    /**
     * Method gets the current authentication state.
     *
     * @return boolean.
     */
    boolean isAuthenticated();

    /**
     * Method gets the authentication time.
     * Is null if !isAuthenticated().
     *
     * @return Date.
     */
    Date getAuthenticationTime();

}
