package org.n52.security.authentication.loginmodule;

import java.io.FileWriter;
import java.io.IOException;
import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.log4j.Logger;
import org.dom4j.Attribute;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.Element;
import org.dom4j.Node;
import org.dom4j.io.OutputFormat;
import org.dom4j.io.XMLWriter;
import org.n52.security.common.util.XMLUtilsDom4j;
import org.n52.security.common.util.XPathHelper;
import org.xml.sax.InputSource;

public class FileLoginUserManager {
	
	 private static Logger sLogger = Logger.getLogger(FileLoginUserManager.class);
	 
	 private Map userMap;
	 private URL sUsersFileUrl;

	 public FileLoginUserManager(URL sUsersFileUrl) throws DocumentException, IOException{
		 this.sUsersFileUrl = sUsersFileUrl;
		 userMap = loadUsers();
	 }
	 
	 private Map loadUsers() throws DocumentException, IOException {
		Document pUsersRepositoryDoc = XMLUtilsDom4j.read(new InputSource(sUsersFileUrl.openStream()));
    	Map lReturnMap = new HashMap();
    	List lUserNodes = pUsersRepositoryDoc.selectNodes("//users:User");
    	for (Iterator iter = lUserNodes.iterator(); iter.hasNext();) {
    		FileLoginUser tUser = new FileLoginUser((Node) iter.next());
    		if (lReturnMap.put(tUser.getUsername(), tUser) != null) {
    			sLogger.warn("Duplicate username: "+tUser.getUsername());
    		}

		}
    	return lReturnMap;
    }
	 
	public FileLoginUser getUser(String username){
		boolean doesUsernameExist = userMap.containsKey(username);
		if(doesUsernameExist){
			return (FileLoginUser) userMap.get(username);
		}
		return null;
	}
	
	public List getAllUsers(){
		List userList = new ArrayList();
		Set userSet = userMap.keySet();
		Iterator userIter = userSet.iterator();
		while(userIter.hasNext()){
			userList.add(userIter.next());
		}
		return userList;
		
	}

	public void addUser(String username, String password) throws DocumentException, IOException {
		
		FileLoginUser user = getUser(username);
		if(user == null){
		
			Document pUsersRepositoryDoc = XMLUtilsDom4j.read(new InputSource(sUsersFileUrl.openStream()));
			Element rootElement = pUsersRepositoryDoc.getRootElement();
			rootElement.addElement("User")
						.addAttribute("username", username)
						.addAttribute("password", password)
						.addAttribute("realname", username);
			
			writeToFile(pUsersRepositoryDoc);
			userMap = loadUsers();
		}
	}

	private void writeToFile(Document pUsersRepositoryDoc) throws IOException {
		String newURL = sUsersFileUrl.toString().substring(6);
		OutputFormat format = OutputFormat.createPrettyPrint();
		XMLWriter writer = new XMLWriter(
		    new FileWriter( newURL ),format
		);
		writer.write( pUsersRepositoryDoc );
		writer.close();
	}

	public void removeUser(String username) throws DocumentException, IOException {
		Document pUsersRepositoryDoc = XMLUtilsDom4j.read(new InputSource(sUsersFileUrl.openStream()));
		Element root = pUsersRepositoryDoc.getRootElement();
		
		// iterate through child elements of root with element name "foo"
		Iterator elemIter = root.elementIterator( "User" );
        while (elemIter.hasNext()) {
           Element curElem = (Element) elemIter.next();
           Iterator attIter = curElem.attributeIterator();
           Attribute curAtt = (Attribute) attIter.next();
           String value = curAtt.getValue();
           if(value.equalsIgnoreCase(username)){
        	   root.remove(curElem);
           }
        }
        writeToFile(pUsersRepositoryDoc);
        userMap = loadUsers();
	}
	
	public Map getUserMap(){
		return new HashMap(userMap);
	}
	
}
