/*******************************************************************************
 * Copyright  2007 52North Initiative for Geospatial Open Source Software GmbH
 *
 * Author: Marko Reiprecht, con terra GmbH
 *
 * Contact: Andreas Wytzisk, 52North Initiative for Geospatial Open Source
 * Software GmbH, Martin-Luther-King-Weg 24, 48155 Muenster, Germany,
 * info@52north.org
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; even without the implied WARRANTY OF MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundations web page, http://www.fsf.org.
 *
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.authentication.principals;

import java.io.Serializable;

/**
 * Class RolePrincipal represents a role(-identity) of a user.
 * <p/>
 *
 * @author Marko Reiprecht
 *         Created on 16.09.2007
 * @version $Revision: $
 */
public class RolePrincipal extends NamePrincipal implements Serializable {

    /**
     * The serialVersionUID.
     *
     * @see java.io.Serializable
     */
    private static final long serialVersionUID = -1423592217263898411L;


    /**
     * Creates a role principal with the given name and valid in the global scope.
     * <p/>
     * It throws an IllegalArgumentException if one of the arguments is null.
     *
     * @param name a role name != null.
     * @throws IllegalArgumentException if one of the arguments is null.
     */
    public RolePrincipal(final String name) throws IllegalArgumentException {
        super(name, Scope.GLOBAL);
    }

    /**
     * Creates a role principal with the given name and valid only for the specified scope.
     * <p/>
     * It throws an IllegalArgumentException if one of the arguments is null.
     *
     * @param name  a role name != null.
     * @param scope the scope of the role != null.
     * @throws IllegalArgumentException if one of the arguments is null.
     */
    public RolePrincipal(final String name, final Scope scope) throws IllegalArgumentException {
        super(name, scope);
    }
}
