/****************************************************************
 SDI Security Services

 Copyright (C) 2004 by con terra GmbH

 Author: Dieter St\u00fcken

 Contact: Albert Remke, con terra GmbH, Martin-Luther-King-Weg 24,
 48155 Muenster, Germany, 52n@conterra.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 version 2 as published by the Free Software Foundation.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program (see gnu-gpl v2.txt); if not, write to
 the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA  02111-1307, USA or visit the web page of the Free
 Software Foundation, http://www.fsf.org.
 ****************************************************************/

package org.n52.security.common.util;

import java.net.URL;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;
import java.util.StringTokenizer;
import org.apache.commons.httpclient.Credentials;
import org.apache.commons.httpclient.ProxyHost;
import org.apache.commons.httpclient.UsernamePasswordCredentials;

/**
 *
 */
public class ProxyManager {

    /**
     * evaluates the system properties to identify a proxy host.
     *
     * @param pProtocol could be http || https
     */
    private ProxyHost getProxyHost(String pProtocol) {
        return extractProxyHost(System.getProperty(pProtocol + ".proxyHost"),
                                System.getProperty(pProtocol + ".proxyPort"));
    }

    private ProxyHost extractProxyHost(String pProxyName, String pProxyPort) {
        if (pProxyName != null && pProxyName.length() > 0) {
            if (pProxyPort != null) {
                int port = Integer.parseInt(pProxyPort);
                return new ProxyHost(pProxyName, port);
            }
        }
        return null;
    }

    /**
     * evaluates system properties to get a collection of non proxy hosts
     *
     * @param pProtocol could be http || https
     */
    private Set getNonProxyHostNames(String pProtocol) {
        // create empty set
        Set nonProxyHostNames = new HashSet();
        nonProxyHostNames.add("localhost");
        nonProxyHostNames.add("127.0.0.1");
        return getNonProxyHostSet(System.getProperty(pProtocol + ".nonProxyHosts"), nonProxyHostNames);

    }

    private Set getNonProxyHostSet(String pNonProxyHostNameString, Set pNonProxyHostNames) {
        if (pNonProxyHostNameString != null && pNonProxyHostNameString.length() > 0) {
            StringTokenizer stok = new StringTokenizer(pNonProxyHostNameString, "|");
            while (stok.hasMoreTokens()) {
                String name = stok.nextToken();
                pNonProxyHostNames.add(name.trim());
            }
        }
        return pNonProxyHostNames;
    }

    /**
     * analyzes the given URL to find a proxy host to use or returns null if the host of the url is a
     * nonProxyHost.
     *
     * @param pUrl to analyze
     * @return applicable proxy host or null
     */
    public ProxyHost getProxyHost(final URL pUrl) {
        Iterator nonproxyHosts = getNonProxyHostNames(pUrl.getProtocol()).iterator();
        String host = pUrl.getHost();
        while (nonproxyHosts.hasNext()) {
            String nonproxyhost = (String) nonproxyHosts.next();
            if (nonproxyhost.startsWith("*")) {
                if (host.endsWith(nonproxyhost.substring(1))) {
                    return null;
                }
            } else {
                if (host.equals(nonproxyhost)) {
                    return null;
                }
            }
        }
        return getProxyHost(pUrl.getProtocol());
    }

    public Credentials getProxyCredentials(URL pURL) {
        String lUserName = System.getProperty(pURL.getProtocol() + ".proxyUser");
        String lPassword = System.getProperty(pURL.getProtocol() + ".proxyPassword");
        if (lUserName != null && lUserName.length() > 0) {
            return new UsernamePasswordCredentials(lUserName, lPassword);
        }
        return null;
    }
}
