/*******************************************************************************
 * Copyright  2007 52North Initiative for Geospatial Open Source Software GmbH
 *
 * Author: Marko Reiprecht, con terra GmbH
 *
 * Contact: Andreas Wytzisk, 52North Initiative for Geospatial Open Source
 * Software GmbH, Martin-Luther-King-Weg 24, 48155 Muenster, Germany,
 * info@52north.org
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; even without the implied WARRANTY OF MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundations web page, http://www.fsf.org.
 *
 ******************************************************************************/
/* $Id: PDPRequest.java 1149 2008-08-05 11:48:03Z MarkoReiprecht $ */
package org.n52.security.decision;

import java.io.Serializable;
import org.n52.security.common.attributes.Attributes;

/**
 * This class represents a decision requests to a DecisionService.
 *
 * @author Bastian Schaeffer
 * @author Marko Reiprecht
 * @version $Revision: 1149 $
 */
public class PDPRequest implements Serializable {

    // ------------------------------ FIELDS ------------------------------

    private static final long serialVersionUID = 9008207828743099624L;

    protected Target m_target;
    protected Attributes m_environment;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor creates a new instance.
     * With empty environment.
     *
     * @param target the target.
     */
    public PDPRequest(final Target target) {
        if (target == null) {
            throw new IllegalArgumentException("<target> must not null");
        }
        m_target = target;
        m_environment = new Attributes();
    }

    /**
     * Constructor creates a new instance.
     *
     * @param target      the target.
     * @param environment the environment.
     */
    public PDPRequest(final Target target, final Attributes environment) {
        if (target == null) {
            throw new IllegalArgumentException("<target> must not null");
        }
        m_target = target;
        if (environment == null) {
            throw new IllegalArgumentException("<environment> must not null");
        }
        m_environment = environment;
    }

    // --------------------- GETTER / SETTER METHODS ---------------------

    /**
     * Method gets the environment.
     *
     * @return Environment.
     */
    public Attributes getEnvironment() {
        return m_environment;
    }

    /**
     * Method gets the target.
     *
     * @return Target.
     */
    public Target getTarget() {
        return m_target;
    }

    // ------------------------ CANONICAL METHODS ------------------------

    /**
     * Method equals.
     *
     * @param o the o.
     * @return boolean.
     */
    public boolean equals(final Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof PDPRequest)) {
            return false;
        }

        final PDPRequest that = (PDPRequest) o;

        if (!m_environment.equals(that.m_environment)) {
            return false;
        }
        if (!m_target.equals(that.m_target)) {
            return false;
        }

        return true;
    }

    /**
     * Method hashCode.
     *
     * @return int.
     */
    public int hashCode() {
        int result;
        result = m_target.hashCode();
        result = 31 * result + m_environment.hashCode();
        return result;
    }

    /**
     * Method toString.
     *
     * @return String.
     */
    public String toString() {
        final StringBuffer sb = new StringBuffer();
        sb.append("org.n52.security.decision.PDPRequest");
        sb.append("{target=").append(getTarget());
        sb.append(", environment=").append(getEnvironment());
        sb.append('}');
        return sb.toString();
    }
}