/****************************************************************
 SDI Security Services

 Copyright (C) 2004 by con terra GmbH

 Author: Jan Drewnak

 Contact: Albert Remke, con terra GmbH, Martin-Luther-King-Weg 24,
 48155 Muenster, Germany, 52n@conterra.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 version 2 as published by the Free Software Foundation.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program (see gnu-gpl v2.txt); if not, write to
 the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA  02111-1307, USA or visit the web page of the Free
 Software Foundation, http://www.fsf.org.
 ****************************************************************/

package org.n52.security.enforcement.artifact;

import org.apache.log4j.Logger;

import java.io.*;

/**
 * @author <a href="mailto:broering@52north.org">Arne Broering</a>
 */
public class StreamPayload implements Payload {
    private static final Logger sLogger = Logger.getLogger(TextualPayload.class);

    protected byte[] mOriginalBytes;
    protected String mCharset;

    /**
     * Creates a new StreamPayload.
     *
     */
    public StreamPayload(InputStream pIn,String pCharset) throws IOException {
        mCharset = pCharset;
        mOriginalBytes = copyStream(pIn);
    }

    private byte[] copyStream(InputStream pIn) throws IOException {
        ByteArrayOutputStream lOutputStream = new ByteArrayOutputStream();

        byte[] lBuffer = new byte[128];
        int lLen = -1;

        while ((lLen = pIn.read(lBuffer))!=-1){
            lOutputStream.write(lBuffer,0,lLen);
        }

        return lOutputStream.toByteArray();
    }

    public InputStream getAsStream() {
        return new ByteArrayInputStream(mOriginalBytes);
    }


    public String toString() {
        try {
            if (mCharset!=null)
                return new String(mOriginalBytes, mCharset);
            else
                return new String(mOriginalBytes,"UTF-8"); // use UTF-8 as default!!
        } catch (UnsupportedEncodingException e) {
            sLogger.error("Fehler !!!", e);
            return new String(mOriginalBytes);
        }
    }

    public byte[] toByteArray() {
   	 return mOriginalBytes;
    }

    public TextualPayload toTextualPayload(){
        try {
            return new TextualPayload(getAsStream(),mCharset);
        } catch (IOException e) {
            sLogger.error("Fehler !!!", e);
            return new TextualPayload(toString(),mCharset);
        }
    }
}
