/****************************************************************
SDI Security Services

Copyright (C) 2004 by con terra GmbH

Author: Jan Drewnak

Contact: Albert Remke, con terra GmbH, Martin-Luther-King-Weg 24,
48155 Muenster, Germany, 52n@conterra.de

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
version 2 as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program (see gnu-gpl v2.txt); if not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA  02111-1307, USA or visit the web page of the Free
Software Foundation, http://www.fsf.org.
****************************************************************/
package org.n52.security.enforcement.artifact;

import org.n52.security.common.util.StringInputStream;
import org.apache.log4j.Logger;

import java.io.*;


/**
 *
 */
public class TextualPayload implements Payload {
    private static final Logger sLogger = Logger.getLogger(TextualPayload.class);
	private String mPayload;
    private String mStreamCharset;

    public TextualPayload(InputStream pInputStream,String pCharsetName)
            throws IOException {
        mStreamCharset = pCharsetName;
        init(new InputStreamReader(pInputStream,pCharsetName));
    }

    public TextualPayload(String pContent,String pStreamCharset) {
        mPayload = pContent;
        mStreamCharset = pStreamCharset;
    }

    private void init(Reader pReader) throws IOException {
        BufferedReader lReader = new BufferedReader(pReader,256);
        StringBuffer lBuffer = new StringBuffer(256);
        String lLine = null;
        try{
        while((lLine=lReader.readLine())!=null){
            lBuffer.append(lLine).append("\n");
        }
        }finally{
            lReader.close();
        }
        if (lBuffer.length()>0)
            mPayload = lBuffer.substring(0);
    }

	public InputStream getAsStream() {
        try {
            //return new ByteArrayInputStream(mPayload.getBytes(mStreamCharset!=null? mStreamCharset:"UTF-8"));
            return new StringInputStream(mPayload,(mStreamCharset!=null && !mStreamCharset.equals(""))? mStreamCharset:"UTF-8");
        } catch (UnsupportedEncodingException e) {
            sLogger.error("Fehler !!!", e);
            return new ByteArrayInputStream(mPayload.getBytes());
        }
    }

	public String toString() {
		return mPayload;
	}

}
