/****************************************************************
 SDI Security Services

 Copyright (C) 2005 by con terra GmbH

 Author: Marko Reiprecht

 Contact: Albert Remke, con terra GmbH, Martin-Luther-King-Weg 24,
 48155 Muenster, Germany, 52n@conterra.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 version 2 as published by the Free Software Foundation.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program (see gnu-gpl v2.txt); if not, write to
 the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA  02111-1307, USA or visit the web page of the Free
 Software Foundation, http://www.fsf.org.
 ****************************************************************/
/* $Id: Transferable.java 539 2007-06-22 19:54:20Z jessebluemr $ */
package org.n52.security.enforcement.artifact;

import java.util.Collection;

/**
 * Tasks of Interface Transferable:
 * <ol>
 * <li>A Transferable is a Object, wich is Transported between the Backend and Frontend of the System</li>
 * <li>It holds a PayLoad wich could be writen to different DCPs</li>
 * <li>It holds a Set of TransferAttributes, wich describe the special aspects of the payload,
 * or holds other special Information for different DCPs</li>
 * </ol>
 *
 * @author reiprecht
 */
public interface Transferable {
    /**
     * Gets the PayLoad of this Transferable
     * @return
     */
    public Payload getPayload();
    /**
     * Sets the Payload of this Transferable
     */
    public void setPayload(Payload pPayload);
    /**
     * Returns the Collection of keys, under which TransferAttributes
     * are stored
     * @return
     */
    public Collection getAttributeNames();
    /**
     * Returns the Collection of TransferAttributes which stored in
     * this Transferable
     * @return
     */
    public Collection getAttributes();
    /**
     * Gets the TransferAttribute which are stored under pName
     *
     * @param pName
     * @return  null <==> (!getAttributeNames.contains(pKey) || pKey==null)
     */
    public TransferAttribute getAttribute(String pName);
    /**
     * Gets the Value of the TransferAttribute which are stored under pName
     * @param pName
     * @return  null <==> (!getAttributeNames.contains(pName) || pName==null) <br/>
     *          short for getAttribute(pName).getValue();
     */
    public Object getAttributeValue(String pName);
    /**
     * Adds a Attribute to the Set and stores it under pAttribute.getName()
     *
     * @param pAttribute    The Attribute
     */
    public void addAttribute(TransferAttribute pAttribute);
}
