/****************************************************************
 SDI Security Services

 Copyright (C) 2005 by con terra GmbH

 Author: Marko Reiprecht

 Contact: Albert Remke, con terra GmbH, Martin-Luther-King-Weg 24,
 48155 Muenster, Germany, 52n@conterra.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 version 2 as published by the Free Software Foundation.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program (see gnu-gpl v2.txt); if not, write to
 the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA  02111-1307, USA or visit the web page of the Free
 Software Foundation, http://www.fsf.org.
 ****************************************************************/
/* $Id: TransferableFactory.java 539 2007-06-22 19:54:20Z jessebluemr $ */
package org.n52.security.enforcement.artifact;

import org.apache.log4j.Logger;

import java.io.IOException;
import java.io.InputStream;

/**
 * Tasks of Class TransferableFactory:
 * <ol>
 * <li></li>
 * </ol>
 *
 * @author reiprecht
 */
public class TransferableFactory {

    private final static Logger sLogger = Logger.getLogger(TransferableFactory.class);

    private static TransferableFactory mInstance = new TransferableFactory();

    private TransferableFactory() {
    }

    public static TransferableFactory getInstance() {
        return mInstance;
    }

    public Transferable createTextualTransferable(String pContentType, String pPayLoad, String pTargetCharset) {
        Transferable lTransferable = new TransferableImpl();
        lTransferable.setPayload(new TextualPayload(pPayLoad,pTargetCharset));
        if (pContentType != null) {
            lTransferable.addAttribute(
                    HttpHeaderAttribute.createHttpHeaderAttribute(HttpHeaderAttribute.HEADER_NAME_CONTENTTYPE,
                                                                  pContentType));
        }
        if (pTargetCharset!=null){
            lTransferable.addAttribute(
                    HttpHeaderAttribute.createHttpHeaderAttribute(HttpHeaderAttribute.HEADER_NAME_CONTENTENCODING,pTargetCharset));
        }
        return lTransferable;
    }

    public Transferable createStreamTransferable(String pContentType, InputStream pPayLoad,String pCharset) throws IOException {
        Transferable lTransferable = new TransferableImpl();
        lTransferable.setPayload(new StreamPayload(pPayLoad,pCharset));
        if (pContentType != null) {
            lTransferable.addAttribute(
                    HttpHeaderAttribute.createHttpHeaderAttribute(HttpHeaderAttribute.HEADER_NAME_CONTENTTYPE,
                                                                  pContentType));
        }
        if (pCharset!=null){
            lTransferable.addAttribute(
                    HttpHeaderAttribute.createHttpHeaderAttribute(HttpHeaderAttribute.HEADER_NAME_CONTENTENCODING,pCharset));
        }
        return lTransferable;
    }
}