/*******************************************************************************
 * Copyright  2007 52North Initiative for Geospatial Open Source Software GmbH
 *
 * Author: AUTHOR, COMPANY
 *
 * Contact: Andreas Wytzisk, 52North Initiative for Geospatial Open Source
 * Software GmbH, Martin-Luther-King-Weg 24, 48155 Muenster, Germany,
 * info@52north.org
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; even without the implied WARRANTY OF MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundations web page, http://www.fsf.org.
 *
 ******************************************************************************/
package org.n52.security.precondition;

/**
 * Implementations of this class provide precondition-specific properties that are set by clients to deliver 
 * information for precondition handling. It is <i>not</i> intended that instances of this class acquire these values 
 * by themselves.
 * 
 * @author drewnak
 *
 */
public abstract class PreconditionHandler {

    protected Precondition m_prec = null;
    
//    protected List m_listeners = new ArrayList();
    
    private PreconditionHandler() {
    }

    protected PreconditionHandler(Precondition prec) {
        this();
        m_prec = prec;        
    }

    public Precondition getPrecondition() {
        return m_prec;
    }
    
    /**
     * This mathod should be called <i>after</i> the properties required for precondition handling are set.
     *  
     * @throws PreconditionHandlingException
     */
    public abstract void handle() throws PreconditionHandlingException;
    
//    public List getHandleResultListeners() {
//        return m_listeners;
//    }
    

}

